OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vælg venligst en fil.",
    "File is too big" : "Filen er for stor",
    "The selected file is not an image." : "Den valgte fil er ikke et billede.",
    "The selected file cannot be read." : "Den valgte fil kan ikke læses.",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize-direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overskrider MAX_FILE_SIZE-direktivet, der blev angivet i HTML-formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet",
    "No file was uploaded" : "Ingen fil blev uploadet",
    "Missing a temporary folder" : "Mangler en midlertidig mappe",
    "Could not write file to disk" : "Kunne ikke skrive fil til disk",
    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede filoverførslen",
    "Invalid file provided" : "Der er angivet en ugyldig fil",
    "No image or file provided" : "Ingen fil eller billede givet",
    "Unknown filetype" : "Ukendt filtype",
    "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
    "Invalid image" : "Ugyldigt billede",
    "State token does not match" : "Forkert tilstandsnøgle",
    "Invalid app password" : "Forkert app kodeord",
    "Could not complete login" : "Kunne ikke gennemføre login",
    "State token missing" : "Tilstands token mangler",
    "Your login token is invalid or has expired" : "Din login token er ugyldigt eller udløbet",
    "Please use original client" : "Anvend venligst original klient",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denne fællesskabsudgivelse af Nextcloud er ikke understøttet, og push-meddelelser er begrænsede.",
    "Login" : "Login",
    "Unsupported email length (>255)" : "Ikke-understøttet e-maillængde (>255)",
    "Password reset is disabled" : "Muligheden for at nulstille adgangskoden er deaktiveret",
    "Could not reset password because the token is expired" : "Kunne ikke nulstille adgangskoden, fordi tokenet er udløbet",
    "Could not reset password because the token is invalid" : "Kunne ikke nulstille adgangskoden, fordi tokenet er ugyldigt",
    "Password is too long. Maximum allowed length is 469 characters." : "Det valgte kodeord er for langt. Maximum længden er 469 tegn.",
    "%s password reset" : "%s adgangskode nulstillet",
    "Password reset" : "Nulstil adgangskode",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik på knappen for at nulstille din adgangskode. Hvis ikke det er dig selv der har efterspurgt at få nulstillet din adgangskode, ignorer denne e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik på linket for at nulstille din adgangskode. Hvis ikke det er dig selv der har efterspurgt at få nulstillet din adgangskode, ignorer denne e-mail.",
    "Reset your password" : "Nulstil din adgangskode",
    "The given provider is not available" : "Den givne udbyder er ikke tilgængelig",
    "Task not found" : "Opgaven blev ikke fundet",
    "Internal error" : "Intern fejl",
    "Not found" : "Ikke fundet",
    "Node is locked" : "Grenen er låst",
    "Bad request" : "Forkert forespørgsel",
    "Requested task type does not exist" : "Den ønskede opgavetype findes ikke",
    "Necessary language model provider is not available" : "Nødvendig sprogmodeludbyder er ikke tilgængelig",
    "No text to image provider is available" : "Ingen tilgængelig tekst-til-billede funktionalitet",
    "Image not found" : "Billede ikke fundet",
    "No translation provider available" : "Ingen tilgængelig oversættelsesudbyder",
    "Could not detect language" : "Kunne ikke finde sprog",
    "Unable to translate" : "Kan ikke oversætte",
    "No valid filters provided" : "Ingen gyldige filtre leveret",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparationstrin:",
    "Repair info:" : "Reparationsinfo:",
    "Repair warning:" : "Reparationsadvarsel:",
    "Repair error:" : "Reparationsfejl:",
    "Nextcloud Server" : "Nextcloud server",
    "Some of your link shares have been removed" : "Nogle af dine delte links er blevet fjernet",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pga et sikkerhedshul har vi været nødt til at fjerne nogle af dine delte links. Se linket for mere information.",
    "The account limit of this instance is reached." : "Konto grænsen for denne instans er nået.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Indtast din abonnementsnøgle i support app for at øge konto grænsen. Dette giver dig også alle yderligere fordele, som Nextcloud Enterprise tilbyder og anbefales stærkt til driften i virksomheder.",
    "Learn more ↗" : "Lær mere ↗",
    "Preparing update" : "Forbereder opdatering",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Brug venligst kommandolinjeopdateringen, fordi opdatering via browser er deaktiveret i din config.php.",
    "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
    "Turned off maintenance mode" : "Slå vedligeholdelsestilstand fra",
    "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
    "Updating database schema" : "Opdaterer database skema",
    "Updated database" : "Opdaterede database",
    "Update app \"%s\" from App Store" : "Opdater app \"%s\" fra App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om databaseskemaet for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
    "Updated \"%1$s\" to %2$s" : "Opdaterede \"%1$s\" til %2$s",
    "Set log level to debug" : "Sæt logningsniveau til fejlfinding",
    "Reset log level" : "Nulstil logningsniveau",
    "Starting code integrity check" : "Begynder tjek af kodeintegritet",
    "Finished code integrity check" : "Fuldførte tjek af kodeintegritet",
    "%s (incompatible)" : "%s (inkompatibel)",
    "The following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
    "Already up to date" : "Allerede opdateret",
    "Windows Command Script" : "Windows kommandoscript",
    "Electronic book document" : "Elektronisk bog dokument",
    "TrueType Font Collection" : "TrueType Font samling",
    "Web Open Font Format" : "Web Open Font format",
    "GPX geographic data" : "GPX geografiske data",
    "Gzip archive" : "Gzip arkiv",
    "Adobe Illustrator document" : "Adobe Illustrator dokument",
    "Java source code" : "Java kildekode",
    "JavaScript source code" : "JavaScript kildekode",
    "JSON document" : "JSON dokument",
    "Microsoft Access database" : "Microsoft Access database",
    "Microsoft OneNote document" : "Microsoft OneNote dokument",
    "Microsoft Word document" : "Microsoft Word dokument",
    "Unknown" : "Ukendt",
    "PDF document" : "PDF dokument",
    "PostScript document" : "PostScript dokument",
    "RSS summary" : "RSS sammendrag",
    "Android package" : "Android pakke",
    "KML geographic data" : "KML geografiske data",
    "KML geographic compressed data" : "KML geografiske komprimerede data",
    "Lotus Word Pro document" : "Lotus Word Pro dokumentet",
    "Excel spreadsheet" : "Excel regneark",
    "Excel add-in" : "Excel udvidelse",
    "Excel 2007 binary spreadsheet" : "Excel 2007 binært regneark",
    "Excel spreadsheet template" : "Excel regnearksskabelon",
    "Outlook Message" : "Outlook besked",
    "PowerPoint presentation" : "PowerPoint præsentation",
    "PowerPoint add-in" : "PowerPoint udvidelse",
    "PowerPoint presentation template" : "PowerPoint præsentationsskabelon",
    "Word document" : "Word dokument",
    "ODF formula" : "ODF formel",
    "ODG drawing" : "ODG tegning",
    "ODG drawing (Flat XML)" : "ODG tegning (Flad XML)",
    "ODG template" : "ODG skabelon",
    "ODP presentation" : "ODP præsentation",
    "ODP presentation (Flat XML)" : "ODP præsentation (Flad XML)",
    "ODP template" : "ODP skabelon",
    "ODS spreadsheet" : "ODS regneark",
    "ODS spreadsheet (Flat XML)" : "ODS regneark (Flad XML)",
    "ODS template" : "ODS skabelon",
    "ODT document" : "ODT dokument",
    "ODT document (Flat XML)" : "ODT dokument (Flad XML)",
    "ODT template" : "ODT skabelon",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 præsentation",
    "PowerPoint 2007 show" : "PowerPoint 2007 show",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 præsentationsskabelon",
    "Excel 2007 spreadsheet" : "Excel 2007 regneark",
    "Excel 2007 spreadsheet template" : "Excel 2007 regnearksskabelon",
    "Word 2007 document" : "Word 2007 dokument",
    "Word 2007 document template" : "Word 2007 dokumentskabelon",
    "Microsoft Visio document" : "Microsoft Visio dokument",
    "WordPerfect document" : "WordPerfect dokument",
    "7-zip archive" : "7-zip arkiv",
    "Blender scene" : "Blender scene",
    "Bzip2 archive" : "Bzip2 arkiv",
    "Debian package" : "Debian pakke",
    "FictionBook document" : "FictionBook dokument",
    "Unknown font" : "Ukendt font",
    "Krita document" : "Krita dokument",
    "Mobipocket e-book" : "Mobipocket e-bog",
    "Windows Installer package" : "Windows installerbar pakke",
    "Perl script" : "Perl script",
    "PHP script" : "PHP script",
    "Tar archive" : "Tar arkiv",
    "XML document" : "XML dokument",
    "YAML document" : "YAML dokument",
    "Zip archive" : "Zip arkiv",
    "Zstandard archive" : "Zstandard arkiv",
    "AAC audio" : "AAC lyd",
    "FLAC audio" : "FLAC lyd",
    "MPEG-4 audio" : "MPEG-4 lyd",
    "MP3 audio" : "MP3 lyd",
    "Ogg audio" : "Ogg lyd",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard lyd",
    "WebM audio" : "WebM lyd",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast spilleliste",
    "Windows BMP image" : "Windows BMP billede",
    "Better Portable Graphics image" : "Better Portable Graphics billede",
    "EMF image" : "EMF billede",
    "GIF image" : "GIF billede",
    "HEIC image" : "HEIC billede",
    "HEIF image" : "HEIF billede",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 billede",
    "JPEG image" : "JPEG billede",
    "PNG image" : "PNG billede",
    "SVG image" : "SVG billede",
    "Truevision Targa image" : "Truevision Targa billede",
    "TIFF image" : "TIFF billede",
    "WebP image" : "WebP billede",
    "Digital raw image" : "Digital raw billede",
    "Windows Icon" : "Windows ikon",
    "Email message" : "E-mail besked",
    "VCS/ICS calendar" : "VCS/ICS kalender",
    "CSS stylesheet" : "CSS stylesheet",
    "CSV document" : "CSV dokument",
    "HTML document" : "HTML dokument",
    "Markdown document" : "Markdown dokument",
    "Org-mode file" : "Org-mode fil",
    "Plain text document" : "Rå tekst dokument",
    "Rich Text document" : "Rich tekst dokument",
    "Electronic business card" : "Elektronisk firmakort",
    "C++ source code" : "C++ kildekode",
    "LDIF address book" : "LDIF adressebog",
    "NFO document" : "NFO dkcument",
    "PHP source" : "PHP kilde",
    "Python script" : "Python script",
    "ReStructuredText document" : "ReStructuredText dokument",
    "3GPP multimedia file" : "3GPP multimedie fil",
    "MPEG video" : "MPEG video",
    "DV video" : "DV video",
    "MPEG-2 transport stream" : "MPEG-2 transport stream",
    "MPEG-4 video" : "MPEG-4 video",
    "Ogg video" : "Ogg video",
    "QuickTime video" : "QuickTime video",
    "WebM video" : "WebM video",
    "Flash video" : "Flash video",
    "Matroska video" : "Matroska video",
    "Windows Media video" : "Windows Medie video",
    "AVI video" : "AVI video",
    "Done" : "Færdig",
    "Applications menu" : "App menu",
    "Apps" : "Apps",
    "More apps" : "Flere apps",
    "_{count} notification_::_{count} notifications_" : ["{count} underretning","{count} underretninger"],
    "No" : "Nej",
    "Yes" : "Ja",
    "App password" : "App adgangskode",
    "Grant access" : "Giv adgang",
    "The remote URL must include the user." : "Fjern-URL'en skal omfatte brugeren.",
    "Invalid remote URL." : "Ugyldig fjern webadresse.",
    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
    "Federated user" : "Fødereret bruger",
    "user@your-nextcloud.org" : "bruger@din-nextcloud.dk",
    "Create share" : "Opret share",
    "Direct link copied" : "Direkte link kopieret",
    "Please copy the link manually:" : "Kopier venligst linket manuelt:",
    "Custom date range" : " Brugerdefineret datointerval",
    "Pick start date" : "Vælg en startdato",
    "Pick end date" : "Vælg en slutdato",
    "Search in date range" : "Søg i datointerval",
    "Search in current app" : "Søg i nuværende app",
    "Clear search" : "Ryd søgning",
    "Search everywhere" : "Søg overalt",
    "Searching …" : "Søger ...",
    "Start typing to search" : "Start med at skrive for at søge",
    "Minimum search length is {minSearchLength} characters" : "Minimumssøgelængde er {minSearchLength} tegn",
    "No matching results" : "Ingen søgeresultater",
    "Today" : "I dag",
    "Last 7 days" : "Sidste 7 dage",
    "Last 30 days" : "Sidste 30 dage",
    "This year" : "Dette år",
    "Last year" : "Sidste år",
    "Between {startDate} and {endDate}" : "Mellem {startDate} og {endDate}",
    "Unified search" : "Samlet søgning",
    "Search apps, files, tags, messages" : "Søg i apps, filer, tags, beskeder",
    "Places" : "Steder",
    "Date" : "Dato",
    "Search people" : "Søg efter personer",
    "People" : "Personer",
    "Filter in current view" : "Filtrer i den aktuelle visning",
    "Search connected services" : "Søg efter forbundne services",
    "Results" : "Resultater",
    "Load more results" : "Hent flere resultater",
    "Search in" : "Søg i",
    "Log in" : "Log ind",
    "Logging in …" : "Logger på ...",
    "Log in to {productName}" : "Log ind på {productName}",
    "Wrong login or password." : "Forkert brugernavn eller adgangskode.",
    "This account is disabled" : "Denne konto er deaktiveret",
    "Account name or email" : "Brugernavn eller e-mail",
    "Account name" : "Kontonavn",
    "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
    "Please contact your administrator." : "Kontakt venligst din administrator.",
    "Session error" : "Sessionsfejl",
    "It appears your session token has expired, please refresh the page and try again." : "Det ser ud til, at dit sessionstoken er udløbet. Opdater venligst siden og prøv igen.",
    "An internal error occurred." : "Der opstod en intern fejl.",
    "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
    "Password" : "Adgangskode",
    "Log in with a device" : "Log ind med en enhed",
    "Login or email" : "Log ind med e-mail",
    "Your account is not setup for passwordless login." : "Din konto er ikke opsat til kodefri login.",
    "Your connection is not secure" : "Din forbindelse er ikke sikker",
    "Passwordless authentication is only available over a secure connection." : "Kodefri bekræftelse er kun understøttet gennem en sikker forbindelse.",
    "Browser not supported" : "Browser ikke understøttet",
    "Passwordless authentication is not supported in your browser." : "Kodefri bekræftelse er ikke understøttet af din browser.",
    "Reset password" : "Nulstil kodeord",
    "Back to login" : "Tilbage til log in",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne konto eksisterer, er der sendt en besked om nulstilling af adgangskode til dens e-mailadresse. Hvis du ikke modtager det, skal du bekræfte din e-mailadresse og/eller login, tjekke dine spam-/junk-mapper eller bede din lokale administration om hjælp.",
    "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst din administrator.",
    "Password cannot be changed. Please contact your administrator." : "Adgangskoden kan ikke ændres. Kontakt venligst din administrator.",
    "New password" : "Ny adgangskode",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dine filer er krypteret. Det vil ikke være muligt at kunne genskabe din data hvis din adgangskode nulstilles. Hvis du ikke er sikker på hvad du skal gøre, så kontakt venligst din administrator før du fortsætter. Ønsker du at forsætte?",
    "I know what I'm doing" : "Jeg ved, hvad jeg har gang i",
    "Resetting password" : "Nulstilling af adgangskode",
    "Schedule work & meetings, synced with all your devices." : "Skemalagt arbejde og møder, synkroniseret med alle dine enheder.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saml dine kollegaer og venner på et sted ude at lække deres private informationer.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpel email-app som er integreret med Filer, Kontakter og Kalender.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videokald, skærmdeling, online møder og webkonferencer – i din browser og med mobilapps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbejdsdokumenter, regneark og præsentationer, bygget på Collabora Online.",
    "Distraction free note taking app." : "App til at tage noter uden distraktion.",
    "Recommended apps" : "Anbefalede apps",
    "Loading apps …" : "Indlæser apps ...",
    "Could not fetch list of apps from the App Store." : "Kunne ikke hente listen over apps fra App Store.",
    "App download or installation failed" : "App-download eller installation mislykkedes",
    "Cannot install this app because it is not compatible" : "Kan ikke installere denne app, fordi den ikke er kompatibel",
    "Cannot install this app" : "Kan ikke installere denne app",
    "Skip" : "Spring over",
    "Installing apps …" : "Installerer apps ...",
    "Install recommended apps" : "Installer anbefalede apps",
    "Online" : "Online",
    "Away" : "Ikke tilstede",
    "Busy" : "Optaget",
    "Do not disturb" : "Forstyr ikke",
    "Mute all notifications" : "Vis ikke notifikationer",
    "Invisible" : "Usynlig",
    "Appear offline" : "Er offline",
    "Avatar of {displayName}" : "Avatar af {displayName}",
    "Settings menu" : "Indstillingsmenu",
    "Loading your contacts …" : "Indlæser kontakter ...",
    "Looking for {term} …" : "Leder efter {term} …",
    "Search contacts" : "Søg kontakter",
    "Search contacts …" : "Søg efter kontakter ...",
    "Reset search" : "Nulstil søgning",
    "Could not load your contacts" : "Kunne ikke indlæse kontakter.",
    "No contacts found" : "Ingen kontakter",
    "Show all contacts" : "Vis alle kontakter",
    "Install the Contacts app" : "Installer Kontakter-appen",
    "Search" : "Søg",
    "No results for {query}" : "Ingen søgeresultater for {query}",
    "Press Enter to start searching" : "Tast Enter for at starte søgning",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Minimum {minSearchLength} karakter eller flere for at søge","Minimum {minSearchLength} karakterer eller flere for at søge"],
    "An error occurred while searching for {type}" : "Der opstod en fejl under søgningen efter {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Søgningen starter samtidig med indtastningen og resultatet kan vælges med piletasterne",
    "Search for {name} only" : "Søg kun efter {name}",
    "Loading more results …" : "Indlæser flere resultater ...",
    "Forgot password?" : "Glemt adgangskode?",
    "Back to login form" : "Tilbage til login-formularen",
    "Back" : "Tilbage",
    "Login form is disabled." : "Loginformularen er deaktiveret.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-loginformularen er deaktiveret. Brug en anden login-mulighed, hvis den er tilgængelig, eller kontakt din administration.",
    "Connect to your account" : "Forbind til din konto",
    "Security warning" : "Sikkerheds advarsel",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke er igang med at konfigurerer en ny enhed eller app, så er der nogen som forsøger at snyde dig til at give dem adgang til dine data. I dette filfælde skal du ikke forsætte, men istedet kontakte din system administrator.",
    "Alternative log in using app password" : "Alternativ login med app adgangskode",
    "Account connected" : "Kontoen er tilknyttet",
    "Your client should now be connected!" : "Din klient burde være forbundet nu!",
    "You can close this window." : "Du kan lukke dette vindue",
    "Account access" : "Konto adgang",
    "More actions" : "Flere handlinger",
    "User menu" : "Brugermenu",
    "Your guest name: {user}" : "Dit gæstenavn: {user}",
    "You are currently not identified." : "Du er aktuelt ikke identificeret.",
    "Set public name" : "Angiv offentligt navn",
    "Change public name" : "Skift offentligt navn",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong or expired. Please try again or request a new one." : "Adgangskoden er forkert eller udløbet. Forsøg venligst igen eller anmod om et nyt.",
    "Submit" : "Send",
    "Please type in your email address to request a temporary password" : "Indtast venligst din e-mailadresse for at anmode om en midlertidigt adgangskode",
    "Password sent!" : "Adgangskode sendt!",
    "You are not authorized to request a password for this share" : "Du er ikke godkendt til at anmode om en adgangskode til denne delte mappe",
    "Email address" : "Email adresse",
    "Request password" : "Anmod om adgangskode",
    "Forgot password" : "Glemt adgangskode",
    "Password is too weak" : "Adgangskoden er for svag",
    "Password is weak" : "Adgangskoden er svag",
    "Password is average" : "Adgangskoden er middel",
    "Password is strong" : "Adgangskoden er stærk",
    "Password is very strong" : "Adgangskoden er meget stærk",
    "Password is extremely strong" : "Adgangskoden er ekstremt stærk",
    "Unknown password strength" : "Ukendt adgangskodestyrke",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Din datamappe og filer er formentlig tilgængelige fra internettet fordi <code>.htaccess</code> filen ikke virker.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information om hvordan du konfigurerer din server korrekt, {linkStart}se venligst dokumentationen{linkEnd}",
    "Autoconfig file detected" : "Autoconfig fil detekteret",
    "The setup form below is pre-filled with the values from the config file." : "Opsætningsformularen nedenfor er præudfyldt med værdierne fra config filen.",
    "Create administration account" : "Opret administrationkonto",
    "Administration account name" : "Administrationskontonavn",
    "Administration account password" : "Administrationskonto adgangskode",
    "Storage & database" : "Lager & database",
    "Data folder" : "Datamappe",
    "Database configuration" : "Databaskonfiguration",
    "Database type" : "Database-type",
    "Only {firstAndOnlyDatabase} is available." : "Kun {firstAndOnlyDatabase} er tilgængelig.",
    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver yderligere PHP-moduler for at vælge andre databasetyper.",
    "For more details check out the documentation." : "For flere oplysninger, så henvises der til dokumentationen.",
    "Performance warning" : "Ydelses advarsel",
    "You chose SQLite as database." : "Du valgte SQLite som database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bør kun bruges til minimale og udviklingsmæssige servere. Til produktion anbefaler vi en anden database backend.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruger klienter til fil synkronisering, frarådes brugen af SQLite på det kraftigste.",
    "Database connection" : "Database-forbindelse",
    "Database user" : "Databasebruger",
    "Database password" : "Databasekodeord",
    "Database name" : "Navn på database",
    "Database tablespace" : "Database tabelplads",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Angiv et portnummer sammen med hostnavnet (f.eks. localhost:5432).",
    "Database host" : "Databasehost",
    "localhost" : "localhost",
    "Installing …" : "Installerer ...",
    "Install" : "Installer",
    "Need help?" : "Brug for hjælp?",
    "See the documentation" : "Se dokumentationen",
    "{name} version {version} and above" : "{name} version {version} eller nyere",
    "This browser is not supported" : "Denne browser understøttes ikke",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din browser understøttes ikke. Opdater venligst til en nyere version, eller vælg en anden der supporteres. ",
    "Continue with this unsupported browser" : "Fortsæt med denne ikke supporterede browser",
    "Supported versions" : "Supporterede versioner",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Opdateringen er i gang. Forlader du denne side kan der ske fejl i processen som ødelægger din Nextcloud installation",
    "App update required" : "Opdatering af app påkræves",
    "These incompatible apps will be disabled:" : "Følgende inkompatible apps vil blive slået fra:",
    "These apps will be updated:" : "Følgende apps vil blive opdateret:",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Sørg venligst for at sikre, at databasen, config-mappen og data-mappen er blevet sikkerhedskopieret inden vi fortsætter.",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
    "Start update" : "Begynd opdatering",
    "Continue to {productName}" : "Fortsæt til {productName}",
    "Update to {version}" : "Opdatér til {version}",
    "Hide details" : "Skjul detaljer",
    "Show details" : "Vis detaljer",
    "Update needed" : "Opdatering nødvendig",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Brug venligst kommandolinje opdateringsfunktionen til at opdatere fordi du har en stor installation med mere end 50 brugere.",
    "Documentation" : "Dokumentation",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg ved at hvis jeg fortsætter med at bruge opdateringssystemet via denne web forbindelse risikerer jeg at der opstår en timeout og jeg dermed mister mine data. Men jeg har et en backuip og ved hvordan jeg kan genindlæse den hvis det sker",
    "Upgrade via web on my own risk" : "Opdatering via web er på mit eget ansvar.",
    "Search {types} …" : "Søg {types} …",
    "Choose {file}" : "Vælg {file}",
    "Choose" : "Vælg",
    "Copy to {target}" : "Kopiér til {target}",
    "Copy" : "Kopiér",
    "Move to {target}" : "Flyt til {target}",
    "Move" : "Flyt",
    "OK" : "Ok",
    "read-only" : "skrivebeskyttet",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Allerede eksisterende filer",
    "Which files do you want to keep?" : "Hvilke filer ønsker du at beholde?",
    "If you select both versions, the copied file will have a number added to its name." : "Hvis du vælger begge versioner, vil den kopierede fil få tilføjet et nummer til sit navn.",
    "Cancel" : "Annullér",
    "Continue" : "Videre",
    "(all selected)" : "(alle valgt)",
    "({count} selected)" : "({count} valgt)",
    "Error loading file exists template" : "Fejl ved indlæsning af 'fil eksisterer' skabelon",
    "Saving …" : "Gemmer …",
    "Groups" : "Grupper",
    "Group list is empty" : "Gruppelisten er tom",
    "Unable to retrieve the group list" : "Kan ikke hente gruppelisten",
    "seconds ago" : "få sekunder siden",
    "Add to a project" : "Tilføj til et projekt",
    "Rename project" : "Omdøb projekt",
    "Failed to rename the project" : "Kunne ikke omdøbe projektet",
    "Failed to create a project" : "Kunne ikke oprette projekt",
    "Failed to add the item to the project" : "Kunne ikke tilføje objekt til projektet",
    "Connect items to a project to make them easier to find" : "Forbind objekter til et projekt for at gøre dem lettere at finde",
    "Type to search for existing projects" : "Skriv for at søge efter eksisterende projekter",
    "Close \"{dialogTitle}\" dialog" : "Luk dialogboksen \"{dialogTitle}\".",
    "Email length is at max (255)" : "E-maillængde er på maks. (255)",
    "Clipboard not available, please copy manually" : "Udklipsholderen er ikke tilgængeligt, kopier venligst manuelt",
    "Personal" : "Personligt",
    "Accounts" : "Konti",
    "Admin" : "Admin",
    "Help" : "Hjælp",
    "Access forbidden" : "Adgang forbudt",
    "You are not allowed to access this page." : "Du har ikke tilladelse til at tilgå denne side.",
    "Back to %s" : "Tilbage til %s",
    "Page not found" : "Siden blev ikke fundet",
    "The page could not be found on the server or you may not be allowed to view it." : "Siden kunne ikke findes på serveren, eller du har muligvis ikke tilladelse til at se den.",
    "Too many requests" : "For mange resultater",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Der har været for mange forespørgsmåler fra dit netværk. Forsøg igen senere eller kontakt din administrator hvis dette er en fejl.",
    "Error" : "Fejl",
    "Internal Server Error" : "Intern serverfejl",
    "The server was unable to complete your request." : "Serveren var ikke i stand til at udføre din forespørgsel.",
    "If this happens again, please send the technical details below to the server administrator." : "Send venligst detaljerne nedenunder til serveradministratoren, hvis dette sker igen.",
    "More details can be found in the server log." : "Flere detaljer kan fås i serverloggen.",
    "For more details see the documentation ↗." : "Se dokumentationen for flere detaljer.",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Fjernadresse: %s",
    "Request ID: %s" : "Forespørgsels-ID: %s",
    "Type: %s" : "Indtast: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Besked: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Linje: %s",
    "Trace" : "Sporing",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ud til at du forsøger at geninstallere Nextcloud. Men filen CAN_INSTALL mangler fra din konfiguration mappe. Venligst opret filen CAN_INSTALL i din konfiguration mappe for at fortsætte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kunne ikke fjerne CAN_INSTALL fra konfiguration mappen. Venligst fjern denne fil manuelt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden.",
    "Skip to main content" : "Skip til hovedindhold",
    "Skip to navigation of app" : "Skip til navigation af app",
    "Go to %s" : "Gå til %s",
    "Get your own free account" : "Få din egen gratis konto",
    "Previous" : "Tidligere",
    "Two-factor authentication" : "To-faktor autentificering",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Forbedret sikkerhed er aktiveret for din konto. Vælg en nummer to faktor til autentifikation.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunne ikke indlæse mindst en af dine aktiverede to-faktor adgangsmetoder. Kontakt venligst din administrator.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "To-faktor adgang påkrævet, men endnu ikke indstillet for din konto. kontakt venligst din administrator for hjælp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "To-faktor godkendelse er påkrævet men er ikke blevet indstillet for din konto. Venligst fortsæt for at indstillet to-faktor godkendelse. ",
    "Set up two-factor authentication" : "Opsæt to-faktor godkendelse",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "To-faktor adgang påkrævet, men endnu ikke indstillet for din konto. Brug en af dine nødkoder for at logge ind eller kontakt din administrator for hjælp.",
    "Use backup code" : "Anvend backupkode",
    "Cancel login" : "Annullér log på",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Forbedret sikkerhed er påkrævet for din konto. Vælg hvilken udbyder at opsætte:",
    "Error while validating your second factor" : "Fejl i valideringen af din anden faktor login",
    "Access through untrusted domain" : "Adgang gennem et utroværdigt domæne.",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt venligst din administrator. Hvis du er administratoren af denne server, skal du konfigurere \"trusted-domains\" i filen config/config.php. Et eksempel på hvordan kan findes i filen config/config.sample.php",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Nærmere information om hvordan dette indstilles kan findes i %1$sdokumentationen%2$s.",
    "Maintenance mode" : "Vedligeholdelsestilstand",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
    "This page will refresh itself when the instance is available again." : "Denne side vil genopfriske sig selv, når instancen er tilgængelig igen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren, hvis denne meddelelse fortsætter eller optrådte uventet.",
    "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For flere detaljer se {linkstart}dokumentationen ↗{linkend}.",
    "unknown text" : "ukendt tekst",
    "Hello world!" : "Hej verden!",
    "sunny" : "solrigt",
    "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
    "Hello {name}" : "Hej {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dine søgeresultater<script>alert(1)</script></strong>",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
    "An error occurred." : "Der opstod en fejl.",
    "Please reload the page." : "Genindlæs venligst siden.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Opdateringen blev ikke udført korrekt. For mere information <a href=\"{url}\">tjek vores indlæg på forumet</a>, som dækker dette problem.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud fællesskabet</a>.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekund.","Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekunder."],
    "Direct link copied to clipboard" : "Direkte link kopieret til udklipsholder",
    "Searching …" : "Søger …",
    "Logging in …" : "Logger ind …",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har registreret flere ugyldige loginforsøg fra din IP. Derfor bliver din næste login sat op til 30 sekunder.",
    "Loading apps …" : "Henter apps ...",
    "Installing apps …" : "Installerer apps ...",
    "Loading your contacts …" : "Henter dine kontakter …",
    "Looking for {term} …" : "Leder efter {term} …",
    "Search contacts …" : "Søg efter brugere ...",
    "Loading more results …" : "Henter flere resultater...",
    "Search {types} …" : "Søg {types} …",
    "Saving …" : "Gemmer…",
    "Connection to server lost" : "Forbindelsen til serveren er tabt",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Der opstod et problem med at hente siden, prøver igen om %n sekund","Der opstod et problem med at hente siden, prøver igen om %n sekunder"],
    "New in" : "Ny i",
    "View changelog" : "Se ændringslog",
    "Very weak password" : "Meget svagt kodeord",
    "Weak password" : "Svagt kodeord",
    "So-so password" : "Jævnt kodeord",
    "Good password" : "Godt kodeord",
    "Strong password" : "Stærkt kodeord",
    "No action available" : "Ingen funktion tilgængelig",
    "Error fetching contact actions" : "Kunne ikke hente kontakt funktioner",
    "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
    "Restricted" : "Begrænset",
    "Delete" : "Slet",
    "Rename" : "Omdøb",
    "Collaborative tags" : "Collaborative tags",
    "No tags found" : "Ingen tags fundet",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Opret en administrator konto</strong>",
    "New admin account name" : "Navn på ny admin konto",
    "New admin password" : "Ny admin adgangskode",
    "Show password" : "Vis adgangskode",
    "Toggle password visibility" : "Skift adgangskodesynlighed",
    "Configure the database" : "Konfigurer databasen",
    "Only %s is available." : "Kun %s er tilgængelig.",
    "Database account" : "Database konto",
    "Installing …" : "Installerer...",
    "Please log in before granting %1$s access to your %2$s account." : "Log venligst ind for at tildele %1$s adgang til din %2$s konto.",
    "Currently logged in as %1$s (%2$s)." : "Logget ind som %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du er ved at tildele %1$s adgang til din %2$s konto.",
    "%1$s will be updated to version %2$s" : "%1$s vil blive opdateret til version %2$s",
    "The following apps will be updated:" : "Følgende app vil blive opdateret:",
    "The theme %s has been disabled." : "Temaet, %s, er blevet deaktiveret.",
    "Detailed logs" : "Detaljerede logs",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjælp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentation</a>."
},
"nplurals=2; plural=(n != 1);");
